from setuptools import setup, find_namespace_packages

setup(
    name="moderngl-window",
    version="2.4.0",
    description="A cross platform helper library for ModernGL making window creation and resource loading simple",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/moderngl/moderngl_window",
    author="Einar Forselv",
    author_email="eforselv@gmail.com",
    packages=find_namespace_packages(include=['moderngl_window', 'moderngl_window.*']),
    include_package_data=True,
    keywords=['moderngl', 'window', 'context'],
    license='MIT',
    platforms=['any'],
    python_requires='>=3.6',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Games/Entertainment',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Multimedia :: Graphics :: 3D Rendering',
        'Topic :: Scientific/Engineering :: Visualization',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    install_requires=[
        'moderngl<6',
        'pyglet>=1.5.8,<2',
        'numpy>=1.16,<2',
        'pyrr>=0.10.3,<1',
        'Pillow>=5',
    ],
    extras_require={
        "PySide2": ['PySide2<6'],
        "pyqt5": ['PyQt5'],
        "glfw": ['glfw'],
        "PySDL2": ['PySDL2'],
        "pywavefront": ["pywavefront>=1.2.0,<2"],
        "trimesh": ["trimesh>=3.2.6,<4", "scipy>=1.3.2"],
        "tk": ["pyopengltk>=0.0.3"],
        "pygame": ["pygame~=2.0.1"],
    },
    project_urls={
        'Documentation': 'https://moderngl-window.readthedocs.io',
        'ModernGL': 'https://github.com/moderngl/moderngl',
    },
)



# flake8: noqa E741


class KeyModifiers:
    """Namespace for storing key modifiers"""

    shift = False
    ctrl = False
    alt = False

    def __repr__(self):
        return str(self)

    def __str__(self):
        return "<KeyModifiers shift={} ctrl={} alt={}>".format(
            self.shift, self.ctrl, self.alt
        )


class BaseKeys:
    """
    Namespace for mapping key constants.
    This is simply a template for what keys should be mapped for all window libraries
    """

    # Fallback press/release action when window libraries don't have this
    ACTION_PRESS = "ACTION_PRESS"
    ACTION_RELEASE = "ACTION_RELEASE"

    ESCAPE = None
    SPACE = None
    ENTER = None
    PAGE_UP = None
    PAGE_DOWN = None
    LEFT = None
    RIGHT = None
    UP = None
    DOWN = None

    TAB = None
    COMMA = None
    MINUS = None
    PERIOD = None
    SLASH = None
    SEMICOLON = None
    EQUAL = None
    LEFT_BRACKET = None
    RIGHT_BRACKET = None
    BACKSLASH = None
    BACKSPACE = None
    INSERT = None
    DELETE = None
    HOME = None
    END = None
    CAPS_LOCK = None

    F1 = None
    F2 = None
    F3 = None
    F4 = None
    F5 = None
    F6 = None
    F7 = None
    F8 = None
    F9 = None
    F10 = None
    F11 = None
    F12 = None

    NUMBER_0 = None
    NUMBER_1 = None
    NUMBER_2 = None
    NUMBER_3 = None
    NUMBER_4 = None
    NUMBER_5 = None
    NUMBER_6 = None
    NUMBER_7 = None
    NUMBER_8 = None
    NUMBER_9 = None

    NUMPAD_0 = None
    NUMPAD_1 = None
    NUMPAD_2 = None
    NUMPAD_3 = None
    NUMPAD_4 = None
    NUMPAD_5 = None
    NUMPAD_6 = None
    NUMPAD_7 = None
    NUMPAD_8 = None
    NUMPAD_9 = None

    A = None
    B = None
    C = None
    D = None
    E = None
    F = None
    G = None
    H = None
    I = None
    J = None
    K = None
    L = None
    M = None
    N = None
    O = None
    P = None
    Q = None
    R = None
    S = None
    T = None
    U = None
    V = None
    W = None
    X = None
    Y = None
    Z = None
